@@ -40,10 +40,10 @@
 #' @return
 #'
 #' A data frame with an ordered factor column (`interval`), as well as columns
-#' corresponding to the explicit bounds (`lower_bound` and `upper_bound`).
+#' corresponding to the explicit bounds (`lower` and `upper`).
 #' Internally both bound columns are stored as double but it can be taken as
-#' part of the function API that `lower_bound` is coercible to integer without
-#' any coercion to `NA_integer_`. Similarly all values of `upper_bound` apart
+#' part of the function API that `lower` is coercible to integer without
+#' any coercion to `NA_integer_`. Similarly all values of `upper` apart
 #' from those corresponding to `max_upper` can be assumed coercible to integer
 #' (`max_upper` may or may not depending on the given argument).
 #'
@@ -134,8 +134,8 @@ cut_ages <- function(ages, breaks, max_upper = Inf) {
     new_tibble(
         list(
             interval = index,
-            lower_bound = lower_bounds,
-            upper_bound = upper_bounds
+            lower = lower_bounds,
+            upper = upper_bounds
         )
     )
 
